@@ -33,19 +33,19 @@
  * ---------------------------------------------------------------------
  */
 
-use Glpi\Event;
-use Glpi\Toolbox\Sanitizer;
+require_once(__DIR__ . '/_check_webserver_config.php');
 
-include('../inc/includes.php');
+use Glpi\Event;
+
+use function Safe\json_decode;
 
 if (empty($_GET["id"])) {
     $_GET["id"] = '';
 }
 
-Session::checkLoginUser();
-
-if (isset($_UPOST['_actors'])) {
-    $_POST['_actors'] = Sanitizer::sanitize(json_decode($_UPOST['_actors'], true));
+// as _actors virtual field stores JSON, bypass automatic escaping
+if (isset($_POST['_actors'])) {
+    $_POST['_actors'] = json_decode($_POST['_actors'], true);
     $_REQUEST['_actors'] = $_POST['_actors'];
 }
 
@@ -53,6 +53,7 @@ $change = new Change();
 if (isset($_POST["add"])) {
     $change->check(-1, CREATE, $_POST);
 
+    $_POST = $change->enforceReadonlyFields($_POST, true);
     $newID = $change->add($_POST);
     Event::log(
         $newID,
@@ -67,7 +68,7 @@ if (isset($_POST["add"])) {
     } else {
         Html::back();
     }
-} else if (isset($_POST["delete"])) {
+} elseif (isset($_POST["delete"])) {
     $change->check($_POST["id"], DELETE);
 
     $change->delete($_POST);
@@ -80,7 +81,7 @@ if (isset($_POST["add"])) {
         sprintf(__('%s deletes an item'), $_SESSION["glpiname"])
     );
     $change->redirectToList();
-} else if (isset($_POST["restore"])) {
+} elseif (isset($_POST["restore"])) {
     $change->check($_POST["id"], DELETE);
 
     $change->restore($_POST);
@@ -93,9 +94,9 @@ if (isset($_POST["add"])) {
         sprintf(__('%s restores an item'), $_SESSION["glpiname"])
     );
     $change->redirectToList();
-} else if (isset($_POST["purge"])) {
+} elseif (isset($_POST["purge"])) {
     $change->check($_POST["id"], PURGE);
-    $change->delete($_POST, 1);
+    $change->delete($_POST, true);
 
     Event::log(
         $_POST["id"],
@@ -106,9 +107,10 @@ if (isset($_POST["add"])) {
         sprintf(__('%s purges an item'), $_SESSION["glpiname"])
     );
     $change->redirectToList();
-} else if (isset($_POST["update"])) {
+} elseif (isset($_POST["update"])) {
     $change->check($_POST["id"], UPDATE);
 
+    $_POST = $change->enforceReadonlyFields($_POST);
     $change->update($_POST);
     Event::log(
         $_POST["id"],
@@ -120,15 +122,15 @@ if (isset($_POST["add"])) {
     );
 
     Html::back();
-} else if (isset($_POST['addme_observer'])) {
+} elseif (isset($_POST['addme_observer'])) {
     $change->check($_POST['changes_id'], READ);
-    $input = array_merge(Toolbox::addslashes_deep($change->fields), [
+    $input = array_merge($change->fields, [
         'id' => $_POST['changes_id'],
         '_itil_observer' => [
             '_type' => "user",
             'users_id' => Session::getLoginUserID(),
             'use_notification' => 1,
-        ]
+        ],
     ]);
     $change->update($input);
     Event::log(
@@ -140,14 +142,14 @@ if (isset($_POST["add"])) {
         sprintf(__('%s adds an actor'), $_SESSION["glpiname"])
     );
     Html::redirect($change->getFormURLWithID($_POST['changes_id']));
-} else if (isset($_POST['addme_assign'])) {
+} elseif (isset($_POST['addme_assign'])) {
     $change_user = new Change_User();
 
     $change->check($_POST['changes_id'], READ);
     $input = ['changes_id'       => $_POST['changes_id'],
         'users_id'         => Session::getLoginUserID(),
         'use_notification' => 1,
-        'type'             => CommonITILActor::ASSIGN
+        'type'             => CommonITILActor::ASSIGN,
     ];
     $change_user->add($input);
     Event::log(
@@ -159,31 +161,31 @@ if (isset($_POST["add"])) {
         sprintf(__('%s adds an actor'), $_SESSION["glpiname"])
     );
     Html::redirect(Change::getFormURLWithID($_POST['changes_id']));
-} else if (isset($_POST['delete_document'])) {
-    $change->getFromDB((int)$_POST['changes_id']);
+} elseif (isset($_POST['delete_document'])) {
+    $change->getFromDB((int) $_POST['changes_id']);
     $doc = new Document();
     $doc->getFromDB(intval($_POST['documents_id']));
     if ($doc->can($doc->getID(), UPDATE)) {
         $document_item = new Document_Item();
         $found_document_items = $document_item->find([
             $change->getAssociatedDocumentsCriteria(),
-            'documents_id' => $doc->getID()
+            'documents_id' => $doc->getID(),
         ]);
         foreach ($found_document_items as $item) {
-            $document_item->delete(Toolbox::addslashes_deep($item), true);
+            $document_item->delete($item, true);
         }
     }
     Html::back();
-} else if (isset($_POST['addme_as_actor'])) {
+} elseif (isset($_POST['addme_as_actor'])) {
     $id = (int) $_POST['id'];
     $change->check($id, READ);
-    $input = array_merge(Toolbox::addslashes_deep($change->fields), [
+    $input = array_merge($change->fields, [
         'id' => $id,
         '_itil_' . $_POST['actortype'] => [
             '_type' => "user",
             'users_id' => Session::getLoginUserID(),
             'use_notification' => 1,
-        ]
+        ],
     ]);
     $change->update($input);
     Event::log(
@@ -196,17 +198,25 @@ if (isset($_POST["add"])) {
     );
     Html::redirect(Change::getFormURLWithID($id));
 } else {
+    // Add a change from item : format data
+    if (
+        isset($_REQUEST['_add_fromitem'], $_REQUEST['itemtype'], $_REQUEST['items_id'])
+    ) {
+        $_REQUEST['items_id'] = [$_REQUEST['itemtype'] => [$_REQUEST['items_id']]];
+    }
+
     if (isset($_GET['showglobalkanban']) && $_GET['showglobalkanban']) {
-        Html::header(sprintf(__('%s Kanban'), Change::getTypeName(1)), $_SERVER['PHP_SELF'], "helpdesk", "change");
+        Html::header(sprintf(__('%s Kanban'), Change::getTypeName(1)), '', "helpdesk", "change");
         $change::showKanban(0);
     } else {
         $menus = ["helpdesk", "change"];
-        Change::displayFullPageForItem($_REQUEST['id'] ?? 0, $menus, $_REQUEST);
+        Change::displayFullPageForItem((int) ($_REQUEST['id'] ?? 0), $menus, $_REQUEST);
     }
 
-    if (isset($_GET['id']) && ($_GET['id'] > 0)) {
-        $url = KnowbaseItem::getFormURLWithParam($_GET) . '&_in_modal=1&item_itemtype=Change&item_items_id=' . $_GET['id'];
-        if (strpos($url, '_to_kb=') !== false) {
+    $id = (int) $_GET['id'];
+    if ($id > 0) {
+        $url = KnowbaseItem::getFormURLWithParam($_GET) . '&_in_modal=1&item_itemtype=Change&item_items_id=' . $id;
+        if (str_contains($url, '_to_kb=')) {
             Ajax::createIframeModalWindow(
                 'savetokb',
                 $url,
