@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2024 Teclib' and contributors.
+ * @copyright 2015-2025 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -33,13 +33,12 @@
  * ---------------------------------------------------------------------
  */
 
-/** @var array $CFG_GLPI */
+require_once(__DIR__ . '/_check_webserver_config.php');
+
+use Glpi\Application\View\TemplateRenderer;
+
 global $CFG_GLPI;
 
-$SECURITY_STRATEGY = 'no_check';
-
-include('../inc/includes.php');
-
 if (
     !$CFG_GLPI['notifications_mailing']
     || !countElementsInTable(
@@ -47,7 +46,15 @@ if (
         ['itemtype' => 'User', 'event' => 'passwordforget', 'is_active' => 1]
     )
 ) {
-    exit();
+    Session::addMessageAfterRedirect(
+        __s('Sending password forget notification is not enabled.'),
+        true,
+        ERROR
+    );
+    TemplateRenderer::getInstance()->display('forgotpassword.html.twig', [
+        'messages_only' => true,
+    ]);
+    return;
 }
 
 $user = new User();
@@ -67,5 +74,3 @@ if (isset($_REQUEST['password_forget_token'])) {
         User::showPasswordForgetRequestForm();
     }
 }
-
-exit();
