@@ -33,7 +33,9 @@
  * ---------------------------------------------------------------------
  */
 
-include('../inc/includes.php');
+require_once(__DIR__ . '/_check_webserver_config.php');
+
+use function Safe\strtotime;
 
 Session::checkRight("planning", READ);
 
@@ -52,27 +54,36 @@ if (isset($_POST["add"])) {
         }
     }
     Html::back();
-} else if (isset($_POST["delete"])) {
+} elseif (isset($_POST["delete"])) {
     $extevent->check($_POST["id"], DELETE);
     $extevent->delete($_POST);
     $extevent->redirectToList();
-} else if (isset($_POST["restore"])) {
+} elseif (isset($_POST["restore"])) {
     $extevent->check($_POST["id"], DELETE);
     $extevent->restore($_POST);
     $extevent->redirectToList();
-} else if (isset($_POST["purge"])) {
+} elseif (isset($_POST["purge"])) {
     $extevent->check($_POST["id"], PURGE);
-    $extevent->delete($_POST, 1);
+    $extevent->delete($_POST, true);
     $extevent->redirectToList();
-} else if (isset($_POST["purge_instance"])) {
+} elseif (isset($_POST["purge_instance"])) {
     $extevent->check($_POST["id"], PURGE);
     $extevent->deleteInstance((int) $_POST["id"], $_POST['day']);
     $extevent->redirectToList();
-} else if (isset($_POST["update"])) {
+} elseif (isset($_POST["save_instance"])) {
+    $input = $_POST;
+    unset($input['id']);
+    unset($input['rrule']);
+    $input['plan']['begin'] = $_POST['day'] . date(" H:i:s", strtotime($_POST['plan']['begin']));
+    $extevent->check(-1, CREATE, $input);
+    $extevent->add($input);
+    $extevent->deleteInstance((int) $_POST["id"], $_POST['day']);
+    $extevent->redirectToList();
+} elseif (isset($_POST["update"])) {
     $extevent->check($_POST["id"], UPDATE);
     $extevent->update($_POST);
     Html::back();
 } else {
-    $menus = ["helpdesk", "planning", "external"];
+    $menus = ["helpdesk", "planning", "PlanningExternalEvent"];
     PlanningExternalEvent::displayFullPageForItem($_GET["id"], $menus);
 }
