@@ -33,14 +33,14 @@
  * ---------------------------------------------------------------------
  */
 
+require_once(__DIR__ . '/_check_webserver_config.php');
+
+use Glpi\Exception\Http\BadRequestHttpException;
+
 /**
  * @since 0.84.3
  */
 
-include('../inc/includes.php');
-
-Session::checkLoginUser();
-
 $pr = new PlanningRecall();
 
 if (isset($_POST["update"])) {
@@ -48,4 +48,4 @@ if (isset($_POST["update"])) {
     Html::back();
 }
 
-Html::displayErrorAndDie("lost");
+throw new BadRequestHttpException();
