@@ -33,14 +33,14 @@
  * ---------------------------------------------------------------------
  */
 
+require_once(__DIR__ . '/_check_webserver_config.php');
+
 /**
  * @since 0.85
  */
 
 use Glpi\Event;
 
-include('../inc/includes.php');
-
 Session::checkRight('queuednotification', READ);
 
 if (!isset($_GET["id"])) {
@@ -62,7 +62,7 @@ if (isset($_POST["delete"])) {
         sprintf(__('%s deletes an item'), $_SESSION["glpiname"])
     );
     $queuednotification->redirectToList();
-} else if (isset($_POST["restore"])) {
+} elseif (isset($_POST["restore"])) {
     $queuednotification->check($_POST["id"], DELETE);
     $queuednotification->restore($_POST);
 
@@ -75,9 +75,9 @@ if (isset($_POST["delete"])) {
         sprintf(__('%s restores an item'), $_SESSION["glpiname"])
     );
     $queuednotification->redirectToList();
-} else if (isset($_POST["purge"])) {
+} elseif (isset($_POST["purge"])) {
     $queuednotification->check($_POST["id"], PURGE);
-    $queuednotification->delete($_POST, 1);
+    $queuednotification->delete($_POST, true);
 
     Event::log(
         $_POST["id"],
