@@ -33,11 +33,11 @@
  * ---------------------------------------------------------------------
  */
 
+require_once(__DIR__ . '/_check_webserver_config.php');
+
 /**
  * @since 0.85
  */
-include('../inc/includes.php');
-
 $rule = new Rule();
 $rule->getFromDB(intval($_POST['rules_id']));
 
@@ -48,14 +48,14 @@ if (isset($_POST["add"])) {
     $action->add($_POST);
 
     Html::back();
-} else if (isset($_POST["update"])) {
+} elseif (isset($_POST["update"])) {
     $action->check($_POST['id'], UPDATE);
     $action->update($_POST);
 
     Html::back();
-} else if (isset($_POST["purge"])) {
+} elseif (isset($_POST["purge"])) {
     $action->check($_POST['id'], PURGE);
-    $action->delete($_POST, 1);
+    $action->delete($_POST, true);
 
     Html::back();
 }
