@@ -32,15 +32,12 @@
  * ---------------------------------------------------------------------
  */
 
-use function Safe\preg_match;
-use function Safe\scandir;
-
 /**
- * Update from 11.0.1 to 11.0.2
+ * Update from 9.4.6 to 9.4.7
  *
- * @return bool for success (will die for most error)
+ * @return bool
  **/
-function update1101to1102()
+function update946to947()
 {
     /**
      * @var DBmysql $DB
@@ -48,24 +45,13 @@ function update1101to1102()
      */
     global $DB, $migration;
 
-    $updateresult       = true;
-    $ADDTODISPLAYPREF   = [];
-    $DELFROMDISPLAYPREF = [];
-    $update_dir = __DIR__ . '/update_11.0.1_to_11.0.2/';
+    $updateresult     = true;
 
-    $migration->setVersion('11.0.2');
+    $migration->setVersion('9.4.7');
 
-    $update_scripts = scandir($update_dir);
-    foreach ($update_scripts as $update_script) {
-        if (preg_match('/\.php$/', $update_script) !== 1) {
-            continue;
-        }
-        require $update_dir . $update_script;
-    }
+    $DB->update('glpi_events', ['type'   => 'dcrooms'], ['type' => 'serverroms']);
 
     // ************ Keep it at the end **************
-    $migration->updateDisplayPrefs($ADDTODISPLAYPREF, $DELFROMDISPLAYPREF);
-
     $migration->executeMigration();
 
     return $updateresult;
