@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2024 Teclib' and contributors.
+ * @copyright 2015-2025 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -35,6 +35,9 @@
 
 use Glpi\Application\View\TemplateRenderer;
 
+use function Safe\json_encode;
+use function Safe\preg_match;
+
 /**
  * Ajax Class
  **/
@@ -48,7 +51,7 @@ class Ajax
      *
      * @param string   $name    name of the js object
      * @param string   $url     URL to display in modal
-     * @param string[] $options Possible options:
+     * @param array    $options Possible options:
      *     - width      (default 800)
      *     - height     (default 400)
      *     - modal      is a modal window? (default true)
@@ -60,6 +63,9 @@ class Ajax
      */
     public static function createModalWindow($name, $url, $options = [])
     {
+        if (preg_match('/[^\w]+/', $name) === 1) {
+            throw new InvalidArgumentException('Modal name is expected to be a valid javascript variable identifier.');
+        }
 
         $param = [
             'width'           => 800,
@@ -70,7 +76,7 @@ class Ajax
             'title'           => '',
             'extraparams'     => [],
             'display'         => true,
-            'js_modal_fields' => ''
+            'js_modal_fields' => '',
         ];
 
         if (count($options)) {
@@ -89,36 +95,36 @@ class Ajax
             ]
         );
 
-        $out = "<script type='text/javascript'>\n";
-        $out .= "var {$name};\n";
-        $out .= "$(function() {\n";
+        $js = "var {$name};";
+        $js .= "$(function() {";
         if (!empty($param['container'])) {
-            $out .= "   var el = $('#" . Html::cleanId($param['container']) . "');\n";
-            $out .= "   el.addClass('modal');\n";
+            $js .= "   var el = $('#" . jsescape(Html::cleanId($param['container'])) . "');";
+            $js .= "   el.addClass('modal');";
         } else {
-            $out .= "   var el = $('<div class=\"modal\"></div>');";
-            $out .= "   $('body').append(el);\n";
+            $js .= "   var el = $('<div class=\"modal\"></div>');";
+            $js .= "   $('body').append(el);";
         }
-        $out .= "   el.html(" . json_encode($html) . ");\n";
-        $out .= "   {$name} = new bootstrap.Modal(el.get(0), {show: false});\n";
-        $out .= "   el.on(\n";
-        $out .= "      'show.bs.modal',\n";
-        $out .= "      function(evt) {\n";
-        $out .= "         var fields = ";
+        $js .= "   el.html('" . jsescape($html) . "');";
+        $js .= "   {$name} = new bootstrap.Modal(el.get(0), {show: false});";
+        $js .= "   el.on(";
+        $js .= "      'show.bs.modal',";
+        $js .= "      function(evt) {";
+        $js .= "         var fields = ";
         if (is_array($param['extraparams']) && count($param['extraparams'])) {
-            $out .= json_encode($param['extraparams'], JSON_FORCE_OBJECT);
+            $js .= json_encode($param['extraparams'], JSON_FORCE_OBJECT);
         } else {
-            $out .= '{}';
+            $js .= '{}';
         }
-        $out .= ";\n";
+        $js .= ";";
         if (!empty($param['js_modal_fields'])) {
-            $out .= $param['js_modal_fields'] . "\n";
+            $js .= $param['js_modal_fields'] . "";
         }
-        $out .= "         el.find('.modal-body').load('$url', fields);\n";
-        $out .= "      }\n";
-        $out .= "   );\n";
-        $out .= "});\n";
-        $out .= "</script>\n";
+        $js .= "         el.find('.modal-body').load('" . jsescape($url) . "', fields);";
+        $js .= "      }";
+        $js .= "   );";
+        $js .= "});";
+
+        $out = Html::scriptBlock($js);
 
         if ($param['display']) {
             echo $out;
@@ -157,7 +163,7 @@ class Ajax
             'display'       => true,
             'dialog_class'  => 'modal-lg',
             'autoopen'      => false,
-            'reloadonclose' => false
+            'reloadonclose' => false,
         ];
 
         if (count($options)) {
@@ -167,81 +173,82 @@ class Ajax
                 }
             }
         }
-        $url .= (strstr($url, '?') ? '&' :  '?') . '_in_modal=1';
+        $url .= (strstr($url, '?') ? '&' : '?') . '_in_modal=1';
+
+        if (isset($options['extradata'])) {
+            $url .= (strstr($url, '?') ? '&' : '?') . Toolbox::append_params($options['extradata'], '&');
+        }
 
         $rand = mt_rand();
 
-        $html = <<<HTML
-         <div id="$domid" class="modal fade" tabindex="-1" role="dialog">
-            <div class="modal-dialog {$param['dialog_class']}">
-               <div class="modal-content">
-                  <div class="modal-header">
-                     <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
-                     <h3>{$param['title']}</h3>
-                  </div>
-                  <div class="modal-body">
-                     <iframe id='iframe$domid' class="iframe hidden"
-                        width="100%" height="400" frameborder="0">
-                     </iframe>
-                  </div>
-               </div>
+        $domid  = Html::sanitizeDomId($domid);
+
+        $html = '
+            <div id="' . htmlescape($domid) . '" class="modal fade" tabindex="-1" role="dialog">
+                <div class="modal-dialog ' . htmlescape($param['dialog_class']) . '">
+                    <div class="modal-content">
+                        <div class="modal-header">
+                            <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
+                            <h3>' . htmlescape($param['title']) . '</h3>
+                        </div>
+                        <div class="modal-body">
+                            <iframe id="iframe' . htmlescape($domid) . '" class="iframe hidden"
+                                width="100%" height="400" frameborder="0">
+                            </iframe>
+                        </div>
+                    </div>
+                </div>
             </div>
-         </div>
-HTML;
+        ';
 
-        $reloadonclose = $param['reloadonclose'] ? "true" : "false";
-        $autoopen      = $param['autoopen'] ? "true" : "false";
-        $js = <<<JAVASCRIPT
-      $(function() {
-         myModalEl{$rand} = document.getElementById('{$domid}');
-         myModal{$rand}   = new bootstrap.Modal(myModalEl{$rand});
+        $domid = jsescape($domid);
 
-         // move modal to body
-         $(myModalEl{$rand}).appendTo($("body"));
+        $js = '
+            $(function() {
+                myModalEl' . $rand . ' = document.getElementById("' . $domid . '");
+                myModal' . $rand . '   = new bootstrap.Modal(myModalEl' . $rand . ');
 
-         myModalEl{$rand}.addEventListener('show.bs.modal', function () {
-            $('#iframe{$domid}').attr('src','{$url}').removeClass('hidden');
-         });
-         myModalEl{$rand}.addEventListener('hide.bs.modal', function () {
-            if ({$reloadonclose}) {
-               window.location.reload()
-            }
-         });
+                // move modal to body
+                $(myModalEl' . $rand . ').appendTo($("body"));
 
-         if ({$autoopen}) {
-            myModal{$rand}.show();
-         }
+                myModalEl' . $rand . '.addEventListener("show.bs.modal", function () {
+                    $("#iframe' . $domid . '").attr("src", "' . jsescape($url) . '").removeClass("hidden");
+                });
+        ';
+        if ($param['reloadonclose']) {
+            $js .= '
+                myModalEl' . $rand . '.addEventListener("hide.bs.modal", function () {
+                    window.location.reload()
+                });
+            ';
+        }
+        if ($param['autoopen']) {
+            $js .= '
+                myModal' . $rand . '.show();
+            ';
+        }
+        $js .= '
+                document.getElementById("iframe' . $domid . '").onload = function() {
+                    var h = ' . ((int) $param['height']) . ';
+                    var w = ' . ((int) $param['width']) . ';
 
-         document.getElementById('iframe$domid').onload = function() {
-            if ({$param['height']} !== 'undefined') {
-               var h =  {$param['height']};
-            } else {
-               var h =  $('#iframe{$domid}').contents().height();
-            }
-            if ({$param['width']} !== 'undefined') {
-               var w =  {$param['width']};
-            } else {
-               var w =  $('#iframe{$domid}').contents().width();
-            }
+                    $("#iframe' . $domid . '").height(h);
 
-            $('#iframe{$domid}')
-               .height(h);
+                    if (w >= 700) {
+                        $("#' . $domid . ' .modal-dialog").addClass("modal-xl");
+                    } else if (w >= 500) {
+                        $("#' . $domid . ' .modal-dialog").addClass("modal-lg");
+                    } else if (w <= 300) {
+                        $("#' . $domid . ' .modal-dialog").addClass("modal-sm");
+                    }
 
-            if (w >= 700) {
-               $('#{$domid} .modal-dialog').addClass('modal-xl');
-            } else if (w >= 500) {
-               $('#{$domid} .modal-dialog').addClass('modal-lg');
-            } else if (w <= 300) {
-               $('#{$domid} .modal-dialog').addClass('modal-sm');
-            }
+                    // reajust height to content
+                    myModal' . $rand . '.handleUpdate()
+                };
+            });
+        ';
 
-            // reajust height to content
-            myModal{$rand}.handleUpdate()
-         };
-      });
-JAVASCRIPT;
-
-        $out = "<script type='text/javascript'>$js</script>" . trim($html);
+        $out = Html::scriptBlock($js) . trim($html);
 
         if ($param['display']) {
             echo $out;
@@ -276,16 +283,13 @@ JAVASCRIPT;
         $orientation = 'vertical',
         $options = []
     ) {
-        /** @var array $CFG_GLPI */
-        global $CFG_GLPI;
-
         if (count($tabs) === 0) {
             return;
         }
 
         $active_tab = Session::getActiveTab($type);
 
-       // Compute tabs ids.
+        // Compute tabs ids.
         $active_id = null;
         foreach ($tabs as $key => $val) {
             $id = sprintf('tab-%s-%s', str_replace('$', '_', $key), mt_rand());
@@ -298,7 +302,7 @@ JAVASCRIPT;
         }
         $active_id = str_replace('\\', '_', $active_id);
 
-       // Display tabs
+        // Display tabs
         if (count($tabs) > 0) {
             if (count($tabs) == 1) {
                 $orientation = "horizontal";
@@ -319,8 +323,12 @@ JAVASCRIPT;
                 $nav_width      = "";
             }
 
+            if (($options['in_modal'] ?? false)) {
+                $border = "border-0";
+            }
+
             echo "<div class='d-flex card-tabs $flex_container $orientation'>";
-            echo "<ul class='nav nav-tabs $flex_tab' id='$tabdiv_id' $nav_width role='tablist'>";
+            echo "<ul class='nav nav-tabs $flex_tab' id='" . htmlescape($tabdiv_id) . "' $nav_width role='tablist'>";
             $html_tabs = "";
             $html_sele = "";
             $i = 0;
@@ -334,33 +342,71 @@ JAVASCRIPT;
                 $display_class = "d-none";
             }
 
-            foreach ($tabs as $val) {
+            foreach ($tabs as $tab_key => $val) {
                 $target = str_replace('\\', '_', $val['id']);
-                $html_tabs .= "<li class='nav-item $navitemml'>
-               <a class='nav-link justify-content-between $navlinkp $display_class' data-bs-toggle='tab' title='" . strip_tags($val['title']) . "' ";
-                $html_tabs .= " href='" . $val['url'] . (isset($val['params']) ? '?' . $val['params'] : '') . "' data-bs-target='#{$target}'>";
-                $html_tabs .= $val['title'] . "</a></li>";
+                $tab_content_url = $val['url'] . (isset($val['params']) ? '?' . $val['params'] : '');
+                $selected = $active_id == $target ? 'selected' : '';
+                $title = $val['title'];
 
-                $html_sele .= "<option value='$i' " . ($active_id == $target ? "selected" : "") . ">
-               {$val['title']}
-            </option>";
+                // Compute direct link that user can reach in a new tab using
+                // middle mouse click.
+                // TODO: ctrl+click should have the same behavior but it seems
+                // to be caught by the tabs events handler and does not trigger
+                // a new browser tab.
+                $direct_link_url = $_SERVER['REQUEST_URI'];
+                if (count($_GET)) {
+                    $direct_link_url .= count($_GET) ? '&' : '?';
+                } elseif (!str_contains($direct_link_url, "?")) {
+                    $direct_link_url .= "?";
+                }
+                $direct_link_url .= "forcetab=$tab_key";
+
+                if ($tab_key !== -1) {
+                    $html_tabs .= "
+                        <li class='nav-item $navitemml'>
+                            <a
+                                class='nav-link justify-content-between $navlinkp $display_class'
+                                data-bs-toggle='tab'
+                                data-glpi-ajax-content='" . htmlescape($tab_content_url) . "'
+                                href='" . htmlescape($direct_link_url) . "'
+                                data-bs-target='#" . htmlescape($target) . "'
+                            >{$title}</a>
+                        </li>
+                    ";
+                    $html_sele .= "<option value='$i' {$selected}>{$title}</option>";
+                } else {
+                    // All tabs
+                    $html_tabs .= <<<HTML
+                        <li class='nav-item $navitemml'>
+                            <a class='nav-link justify-content-between $navlinkp $display_class' data-bs-toggle='tab'
+                                href='#' data-show-all-tabs="true">{$title}</a>
+                        </li>
+HTML;
+                    $html_sele .= "<option value='$i' {$selected}>{$title}</option>";
+                }
                 $i++;
             }
             echo $html_tabs;
             echo "</ul>";
-            echo "<select class='form-select border-2 border-secondary rounded-0 rounded-top d-md-none mb-2' id='$tabdiv_id-select'>$html_sele</select>";
+            echo "<select class='form-select border-2 rounded-0 rounded-top d-md-none mb-2' id='" . htmlescape($tabdiv_id) . "-select'>$html_sele</select>";
 
             echo "<div class='tab-content p-2 flex-grow-1 card $border' style='min-height: 150px'>";
             foreach ($tabs as $val) {
                 $id = str_replace('\\', '_', $val['id']);
-                echo "<div class='tab-pane fade' role='tabpanel' id='{$id}'></div>";
+                echo "<div data-glpi-tab-content class='tab-pane fade' role='tabpanel' id='" . htmlescape($id) . "'></div>";
             }
             echo  "</div>"; // .tab-content
             echo "</div>"; // .container-fluid
-            $js = "
+
+            $type = jsescape($type);
+            $ID = jsescape($ID);
+            $withtemplate = (int) ($_GET['withtemplate'] ?? 0);
+            $tabdiv_id = jsescape($tabdiv_id);
+            $active_id = jsescape($active_id);
+            $js = <<<JS
          var url_hash = window.location.hash;
          var loadTabContents = function (tablink, force_reload = false, update_session_tab = true) {
-            var url = tablink.attr('href');
+            var url = tablink.data('glpi-ajax-content');
             var base_url = CFG_GLPI.url_base;
             if (base_url === '') {
                 // If base URL is not configured, fallback to current URL domain + GLPI base dir.
@@ -371,33 +417,20 @@ JAVASCRIPT;
 
             const updateCurrentTab = () => {
                 $.get(
-                  '{$CFG_GLPI['root_doc']}/ajax/updatecurrenttab.php',
+                  CFG_GLPI.root_doc + '/ajax/updatecurrenttab.php',
                   {
-                     itemtype: '" . addslashes($type) . "',
+                     itemtype: '$type',
                      id: '$ID',
                      tab_key: href_url_params.get('_glpi_tab'),
-                     withtemplate: " . (int)($_GET['withtemplate'] ?? 0) . "
+                     withtemplate: $withtemplate
                   }
-               ).done(function() {
-                    // try to restore the scroll on a specific anchor
-                    if (url_hash.length > 0) {
-                        // as we load content by ajax, when full page was ready, the anchor was not present
-                        // se we recall it to force the scroll.
-                        window.location.href = url_hash;
-
-                        // animate item with a flash
-                        $(url_hash).addClass('animate__animated animate__shakeX animate__slower');
-
-                        // unset hash (to avoid scrolling when changing tabs)
-                        url_hash   = '';
-                    }
-               });
+               );
             }
             if ($(target).html() && !force_reload) {
                 updateCurrentTab();
                 return;
             }
-            $(target).html('<i class=\"fas fa-3x fa-spinner fa-pulse position-absolute m-5 start-50\"></i>');
+            $(target).html(`<div class="d-flex justify-content-center"><span class="spinner-border spinner-border position-absolute m-5" role="status" aria-hidden="true"></span></div>`);
 
             $.get(url, function(data) {
                $(target).html(data);
@@ -407,21 +440,43 @@ JAVASCRIPT;
                if (update_session_tab) {
                    updateCurrentTab();
                }
+            }).done(function() {
+                // try to restore the scroll on a specific anchor
+                if (url_hash.length > 0) {
+                    // as we load content by ajax, when full page was ready, the anchor was not present
+                    // se we recall it to force the scroll.
+                    window.location.href = url_hash;
+
+                    // animate item with a flash
+                    $(url_hash).addClass('animate__animated animate__shakeX animate__slower');
+
+                    // unset hash (to avoid scrolling when changing tabs)
+                    url_hash   = '';
+                }
+            }).fail(function(data) {
+               $(target).html(data.responseText);
             });
          };
 
          var reloadTab = function (add) {
             var active_link = $('main #tabspanel .nav-item .nav-link.active');
 
-            // Update href and load tab contents
-            var currenthref = active_link.attr('href');
-            active_link.attr('href', currenthref + '&' + add);
+            // Update target AJAX endpoint URL and load tab contents
+            var current_url = active_link.data('glpi-ajax-content');
+            active_link.data('glpi-ajax-content', current_url + '&' + add);
             loadTabContents(active_link, true);
 
-            // Restore href
-            active_link.attr('href', currenthref);
+            // Restore URL
+            active_link.data('glpi-ajax-content', current_url);
          };
 
+         var loadAllTabs = () => {
+             const tabs = $('#$tabdiv_id a[data-bs-toggle=\"tab\"]');
+             tabs.each((index, tab) => {
+                loadTabContents($(tab));
+             });
+         }
+
          $(function() {
             // Keep track of the first load which will be the tab stored in the
             // session.
@@ -431,7 +486,16 @@ JAVASCRIPT;
 
             $('a[data-bs-toggle=\"tab\"]').on('shown.bs.tab', function(e) {
                e.preventDefault();
-               loadTabContents($(this), false, !first_load);
+               if ($(this).attr('data-show-all-tabs') === 'true') {
+                  loadAllTabs();
+                  // show all tabs by adding active and show classes to all tabs
+                  $('#$tabdiv_id').parent().find('.tab-pane').addClass('active show').removeClass('fade');
+               } else {
+                  // Remove active and show classes from all tabs except the one that is clicked
+                  let clicked_tab = $(this).attr('data-bs-target');
+                  $('#$tabdiv_id').parent().find('.tab-pane:not(' + clicked_tab + ')').removeClass('active show');
+                  loadTabContents($(this), false, !first_load);
+               }
             });
 
             // load initial tab
@@ -443,7 +507,7 @@ JAVASCRIPT;
                $('#$tabdiv_id li a').eq($(this).val()).tab('show');
             });
          });
-         ";
+JS;
 
             echo Html::scriptBlock($js);
         }
@@ -453,15 +517,15 @@ JAVASCRIPT;
     /**
      * Javascript code for update an item when another item changed
      *
-     * @param string  $toobserve    id (or array of id) of the select to observe
-     * @param string  $toupdate     id of the item to update
-     * @param string  $url          Url to get datas to update the item
-     * @param array   $parameters   of parameters to send to ajax URL
-     * @param array   $events       of the observed events (default 'change')
-     * @param integer $minsize      minimum size of data to update content (default -1)
-     * @param integer $buffertime   minimum time to wait before reload (default -1)
-     * @param array   $forceloadfor of content which must force update content
-     * @param boolean $display      display or get string (default true)
+     * @param string|array $toobserve    id (or array of id) of the select to observe
+     * @param string       $toupdate     id of the item to update
+     * @param string       $url          Url to get datas to update the item
+     * @param array        $parameters   of parameters to send to ajax URL
+     * @param array        $events       of the observed events (default 'change')
+     * @param integer      $minsize      minimum size of data to update content (default -1)
+     * @param integer      $buffertime   minimum time to wait before reload (default -1)
+     * @param array        $forceloadfor of content which must force update content
+     * @param boolean      $display      display or get string (default true)
      *
      * @return void|string (see $display)
      */
@@ -477,9 +541,8 @@ JAVASCRIPT;
         $display = true
     ) {
 
-        $output  = "<script type='text/javascript'>";
-        $output .= "$(function() {";
-        $output .= self::updateItemOnEventJsCode(
+        $js = "$(function() {";
+        $js .= self::updateItemOnEventJsCode(
             $toobserve,
             $toupdate,
             $url,
@@ -490,7 +553,10 @@ JAVASCRIPT;
             $forceloadfor,
             false
         );
-        $output .=  "});</script>";
+        $js .=  "});";
+
+        $output = Html::scriptBlock($js);
+
         if ($display) {
             echo $output;
         } else {
@@ -502,11 +568,11 @@ JAVASCRIPT;
     /**
      * Javascript code for update an item when a select item changed
      *
-     * @param string  $toobserve  id of the select to observe
-     * @param string  $toupdate   id of the item to update
-     * @param string  $url        Url to get datas to update the item
-     * @param array   $parameters of parameters to send to ajax URL
-     * @param boolean $display    display or get string (default true)
+     * @param string|array $toobserve  id of the select to observe
+     * @param string       $toupdate   id of the item to update
+     * @param string       $url        Url to get datas to update the item
+     * @param array        $parameters of parameters to send to ajax URL
+     * @param boolean      $display    display or get string (default true)
      *
      * @return void|string (see $display)
      */
@@ -532,67 +598,18 @@ JAVASCRIPT;
     }
 
 
-    /**
-     * Javascript code for update an item when a Input text item changed
-     *
-     * @param string  $toobserve    id of the Input text to observe
-     * @param string  $toupdate     id of the item to update
-     * @param string  $url          Url to get datas to update the item
-     * @param array   $parameters   of parameters to send to ajax URL
-     * @param integer $minsize      minimum size of data to update content (default -1)
-     * @param integer $buffertime   minimum time to wait before reload (default -1)
-     * @param array   $forceloadfor of content which must force update content
-     * @param boolean $display      display or get string (default true)
-     *
-     * @return void|string (see $display)
-     */
-    public static function updateItemOnInputTextEvent(
-        $toobserve,
-        $toupdate,
-        $url,
-        $parameters = [],
-        $minsize = -1,
-        $buffertime = -1,
-        $forceloadfor = [],
-        $display = true
-    ) {
-
-        if (count($forceloadfor) == 0) {
-            $forceloadfor = ['*'];
-        }
-       // Need to define min size for text search
-        if ($minsize < 0) {
-            $minsize = 0;
-        }
-        if ($buffertime < 0) {
-            $buffertime = 0;
-        }
-        return self::updateItemOnEvent(
-            $toobserve,
-            $toupdate,
-            $url,
-            $parameters,
-            ["dblclick", "keyup"],
-            $minsize,
-            $buffertime,
-            $forceloadfor,
-            $display
-        );
-    }
-
-
     /**
      * Javascript code for update an item when another item changed (Javascript code only)
      *
-     * @param string  $toobserve    id (or array of id) of the select to observe
-     * @param string  $toupdate     id of the item to update
-     * @param string  $url          Url to get datas to update the item
-     * @param array   $parameters   of parameters to send to ajax URL
-     * @param array   $events       of the observed events (default 'change')
-     * @param integer $minsize      minimum size of data to update content (default -1)
-     * @param integer $buffertime   minimum time to wait before reload (default -1)
-     * @param array   $forceloadfor of content which must force update content
-     * @param boolean $display      display or get string (default true)
+     * @param string|array $toobserve    id (or array of id) of the select to observe
+     * @param string       $toupdate     id of the item to update
+     * @param string       $url          Url to get datas to update the item
+     * @param array        $parameters   of parameters to send to ajax URL
+     * @param array        $events       of the observed events (default 'change')
+     * @param integer      $minsize      minimum size of data to update content (default -1)
+     * @param integer      $buffertime   minimum time to wait before reload (default -1)
+     * @param array        $forceloadfor of content which must force update content
+     * @param boolean      $display      display or get string (default true)
      *
      * @return void|string (see $display)
      */
@@ -607,6 +624,9 @@ JAVASCRIPT;
         $forceloadfor = [],
         $display = true
     ) {
+        if ($buffertime !== -1) {
+            trigger_error('$buffertime parameter has no effect anymore.', E_USER_WARNING);
+        }
 
         if (is_array($toobserve)) {
             $zones = $toobserve;
@@ -616,31 +636,23 @@ JAVASCRIPT;
         $output = '';
         foreach ($zones as $zone) {
             foreach ($events as $event) {
-                if ($buffertime > 0) {
-                    $output .= "var last$zone$event = 0;";
+                if (preg_match('/[^\w]+/', $event) === 1) {
+                    throw new InvalidArgumentException('Event name is expected to contain only alphanumeric chars.');
                 }
-                $output .= Html::jsGetElementbyID(Html::cleanId($zone)) . ".on(
-               '$event',
-               function(event) {";
-               // TODO manage buffer time !!?
-               // if ($buffertime > 0) {
-               //    $output.= "var elapsed = new Date().getTime() - last$zone$event;
-               //          last$zone$event = new Date().getTime();
-               //          if (elapsed < $buffertime) {
-               //             return;
-               //          }";
-               // }
 
+                $zone_id = jsescape(Html::cleanId($zone));
+
+                $output .= "$('#$zone_id').on('$event', function(event) {";
                 $condition = '';
                 if ($minsize >= 0) {
-                    $condition = Html::jsGetElementbyID(Html::cleanId($zone)) . ".val().length >= $minsize ";
+                    $condition = "$('#$zone_id').val().length >= " . ((int) $minsize);
                 }
                 if (count($forceloadfor)) {
                     foreach ($forceloadfor as $value) {
                         if (!empty($condition)) {
-                             $condition .= " || ";
+                            $condition .= " || ";
                         }
-                        $condition .= Html::jsGetElementbyID(Html::cleanId($zone)) . ".val() == '$value'";
+                        $condition .= "$('#$zone_id').val() == '" . jsescape($value) . "'";
                     }
                 }
                 if (!empty($condition)) {
@@ -651,7 +663,7 @@ JAVASCRIPT;
                     $output .= "}";
                 }
                 $output .=  "}";
-                $output .= ");\n";
+                $output .= ");";
             }
         }
         if ($display) {
@@ -680,14 +692,14 @@ JAVASCRIPT;
         $field     = '';
 
         $output    = '';
-       // Old scheme
+        // Old scheme
         if (
             isset($options["update_item"])
             && (is_array($options["update_item"]) || (strlen($options["update_item"]) > 0))
         ) {
             $field     = "update_item";
         }
-       // New scheme
+        // New scheme
         if (
             isset($options["toupdate"])
             && (is_array($options["toupdate"]) || (strlen($options["toupdate"]) > 0))
@@ -698,7 +710,7 @@ JAVASCRIPT;
         if (!empty($field)) {
             $datas = $options[$field];
             if (is_array($datas) && count($datas)) {
-               // Put it in array
+                // Put it in array
                 if (isset($datas['to_update'])) {
                     $datas = [$datas];
                 }
@@ -757,12 +769,12 @@ JAVASCRIPT;
         $display = true
     ) {
 
-        $out = Html::jsGetElementbyID($toupdate) . ".load('$url'\n";
+        $out = sprintf('$("#%s").load("%s"', jsescape($toupdate), jsescape($url));
         if (count($parameters)) {
             $out .= ",{";
             $first = true;
             foreach ($parameters as $key => $val) {
-               // prevent xss attacks
+                // prevent xss attacks
                 if (!preg_match('/^[a-zA-Z_$][0-9a-zA-Z_$]*$/', $key)) {
                     continue;
                 }
@@ -775,17 +787,17 @@ JAVASCRIPT;
 
                 $out .= $key . ":";
                 $regs = [];
-                if (!is_array($val) && preg_match('/^__VALUE(\d+)__$/', $val ?? '', $regs)) {
-                    $out .=  Html::jsGetElementbyID(Html::cleanId($toobserve[$regs[1]])) . ".val()";
-                } else if (!is_array($val) && $val === "__VALUE__") {
-                    $out .=  Html::jsGetElementbyID(Html::cleanId($toobserve)) . ".val()";
+                if (is_string($val) && preg_match('/^__VALUE(\d+)__$/', $val, $regs)) {
+                    $out .= sprintf('$("#%s").val()', jsescape(Html::cleanId($toobserve[$regs[1]])));
+                } elseif (is_string($val) && $val === "__VALUE__") {
+                    $out .= sprintf('$("#%s").val()', jsescape(Html::cleanId($toobserve)));
                 } else {
                     $out .=  json_encode($val);
                 }
             }
-            $out .= "}\n";
+            $out .= "}";
         }
-        $out .= ")\n";
+        $out .= ")";
         if ($display) {
             echo $out;
         } else {
@@ -808,10 +820,12 @@ JAVASCRIPT;
     public static function updateItem($toupdate, $url, $parameters = [], $toobserve = "", $display = true)
     {
 
-        $output  = "<script type='text/javascript'>";
-        $output .= "$(function() {";
-        $output .= self::updateItemJsCode($toupdate, $url, $parameters, $toobserve, false);
-        $output .= "});</script>";
+        $js = "$(function() {";
+        $js .= self::updateItemJsCode($toupdate, $url, $parameters, $toobserve, false);
+        $js .= "});";
+
+        $output = Html::scriptBlock($js);
+
         if ($display) {
             echo $output;
         } else {
