@@ -32,15 +32,19 @@
  *
  * ---------------------------------------------------------------------
  */
+use Glpi\Features\Clonable;
+
+use function Safe\strtotime;
 
 /**
  * Calendar Class
  **/
 class Calendar extends CommonDropdown
 {
-    use Glpi\Features\Clonable;
+    /** @use Clonable<static> */
+    use Clonable;
 
-   // From CommonDBTM
+    // From CommonDBTM
     public $dohistory                   = true;
     public $can_be_translated           = false;
 
@@ -53,7 +57,7 @@ class Calendar extends CommonDropdown
     {
         return [
             Calendar_Holiday::class,
-            CalendarSegment::class
+            CalendarSegment::class,
         ];
     }
 
@@ -80,8 +84,8 @@ class Calendar extends CommonDropdown
     {
 
         $ong = parent::defineTabs($options);
-        $this->addStandardTab('CalendarSegment', $ong, $options);
-        $this->addStandardTab('Calendar_Holiday', $ong, $options);
+        $this->addStandardTab(CalendarSegment::class, $ong, $options);
+        $this->addStandardTab(Calendar_Holiday::class, $ong, $options);
 
         return $ong;
     }
@@ -94,8 +98,8 @@ class Calendar extends CommonDropdown
         $actions = parent::getSpecificMassiveActions($checkitem);
 
         if ($isadmin) {
-            $actions[__CLASS__ . MassiveAction::CLASS_ACTION_SEPARATOR . 'duplicate'] = _x('button', 'Duplicate');
-            $actions[__CLASS__ . MassiveAction::CLASS_ACTION_SEPARATOR . 'addholiday'] = __('Add a close time');
+            $actions[self::class . MassiveAction::CLASS_ACTION_SEPARATOR . 'duplicate'] = _sx('button', 'Duplicate');
+            $actions[self::class . MassiveAction::CLASS_ACTION_SEPARATOR . 'addholiday'] = __s('Add a close time');
         }
         return $actions;
     }
@@ -130,7 +134,7 @@ class Calendar extends CommonDropdown
 
         switch ($ma->getAction()) {
             case 'duplicate': // For calendar duplicate in another entity
-                if (Toolbox::hasTrait($item, \Glpi\Features\Clonable::class)) {
+                if (Toolbox::hasTrait($item, Clonable::class)) {
                     $input = $ma->getInput();
                     $options = [];
                     if ($item->isEntityAssign()) {
@@ -144,10 +148,10 @@ class Calendar extends CommonDropdown
                             ) {
                                 if ($item->can(-1, CREATE, $options)) {
                                     if (method_exists($item, 'clone') && $item->clone($options)) {
-                                         $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_OK);
+                                        $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_OK);
                                     } else {
-                                         $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_KO);
-                                         $ma->addMessage($item->getErrorMessage(ERROR_ON_ACTION));
+                                        $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_KO);
+                                        $ma->addMessage($item->getErrorMessage(ERROR_ON_ACTION));
                                     }
                                 } else {
                                     $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_NORIGHT);
@@ -158,8 +162,8 @@ class Calendar extends CommonDropdown
                                 $ma->addMessage($item->getErrorMessage(ERROR_COMPAT));
                             }
                         } else {
-                             $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_KO);
-                             $ma->addMessage($item->getErrorMessage(ERROR_NOT_FOUND));
+                            $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_KO);
+                            $ma->addMessage($item->getErrorMessage(ERROR_NOT_FOUND));
                         }
                     }
                 } else {
@@ -183,7 +187,7 @@ class Calendar extends CommonDropdown
                         $entities_id = CommonDBTM::getItemEntity('Calendar', $id);
                         if (isset($entities[$entities_id])) {
                             $input = ['calendars_id' => $id,
-                                'holidays_id'  => $input['holidays_id']
+                                'holidays_id'  => $input['holidays_id'],
                             ];
                             if ($calendar_holiday->add($input)) {
                                 $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_OK);
@@ -204,9 +208,6 @@ class Calendar extends CommonDropdown
         parent::processMassiveActionsForOneItemtype($ma, $item, $ids);
     }
 
-    /**
-     * @see Glpi\Features\Clonable::post_clone
-     */
     public function post_clone($source, $history)
     {
         $this->updateDurationCache($this->getID());
@@ -243,7 +244,7 @@ class Calendar extends CommonDropdown
                 $begin_date      = date('m-d', strtotime($holiday['begin_date']));
                 $end_date        = date('m-d', strtotime($holiday['end_date']));
             } else {
-               // Normalize dates to Y-m-d
+                // Normalize dates to Y-m-d
                 $date_to_compare = date('Y-m-d', strtotime($date));
                 $begin_date      = date('Y-m-d', strtotime($holiday['begin_date']));
                 $end_date        = date('Y-m-d', strtotime($holiday['end_date']));
@@ -259,15 +260,17 @@ class Calendar extends CommonDropdown
 
 
     /**
-     * Get active time between to date time for the active calendar
+     * Seconds elapsed between two dates
+     *
+     * Taking opening hours into account unless param $include_inactive_time is true
      *
      * @param string $start                 begin datetime
      * @param string $end                   end datetime
      * @param bool   $include_inactive_time true to just get the time passed between start time and end time
      *
-     * @return int timestamp of delay
+     * @return int seconds elapsed between the two dates, taking opening hours into account.
      *
-     * @FIXME Remove `$include_inactive_time` parameter in GLPI 10.1. It does not seems to be used and makes no sense.
+     * @FIXME Remove `$include_inactive_time` parameter in GLPI 11.0. It does not seems to be used and makes no sense.
      */
     public function getActiveTimeBetween($start, $end, $include_inactive_time = false)
     {
@@ -284,7 +287,7 @@ class Calendar extends CommonDropdown
         $timeend    = strtotime($end);
         $datestart  = date('Y-m-d', $timestart);
         $dateend    = date('Y-m-d', $timeend);
-       // Need to finish at the closing day : set hour to midnight (23:59:59 for PHP)
+        // Need to finish at the closing day : set hour to midnight (23:59:59 for PHP)
         $timerealend = strtotime($dateend . ' 23:59:59');
 
         $activetime = 0;
@@ -316,12 +319,12 @@ class Calendar extends CommonDropdown
                         (($actualdate == $datestart) || ($actualdate == $dateend))
                         && ($cache_duration[$dayofweek] > 0)
                     ) {
-                         $timeoftheday = CalendarSegment::getActiveTimeBetween(
-                             $this->fields['id'],
-                             $dayofweek,
-                             $beginhour,
-                             $endhour
-                         );
+                        $timeoftheday = CalendarSegment::getActiveTimeBetween(
+                            $this->fields['id'],
+                            $dayofweek,
+                            $beginhour,
+                            $endhour
+                        );
                     } else {
                         $timeoftheday = $cache_duration[$dayofweek];
                     }
@@ -408,7 +411,7 @@ class Calendar extends CommonDropdown
      **/
     public function computeEndDate($start, $delay, $additional_delay = 0, $work_in_days = false, $end_of_working_day = false)
     {
-        // TODO 10.1: parameter $work_in_day make calculation for duration exprimed
+        // TODO 11.0: parameter $work_in_day make calculation for duration exprimed
         // in days (e.g "+ 5 days") but we don't have anything for month.
         // +1 month will push the date 30 working day when it should get the next
         // valid calendar date at least one month away from the starting date.
@@ -418,7 +421,7 @@ class Calendar extends CommonDropdown
         }
 
         if (!$this->hasAWorkingDay()) {
-           // Invalid calendar (no working day = unable to find any date inside calendar hours)
+            // Invalid calendar (no working day = unable to find any date inside calendar hours)
             return false;
         }
         $cache_duration = $this->getDurationsCache();
@@ -486,7 +489,7 @@ class Calendar extends CommonDropdown
 
             $lastworkinghour = CalendarSegment::getLastWorkingHour($this->fields['id'], $dayofweek);
             $actualtime      = strtotime(date('Y-m-d', $actualtime) . ' ' . $lastworkinghour);
-        } else if ($work_in_days) {
+        } elseif ($work_in_days) {
             // Computation that is based on a delay expressed in full days.
 
             // Compute Real starting time
@@ -578,10 +581,10 @@ class Calendar extends CommonDropdown
                     }
 
                     if ($delay >= $timeoftheday) {
-                         // Delay is greater or equal than remaining time in day
-                         // -> pass to next day
-                         $actualtime = self::getActualTime($actualtime, DAY_TIMESTAMP, $negative_delay);
-                         $delay      -= $timeoftheday;
+                        // Delay is greater or equal than remaining time in day
+                        // -> pass to next day
+                        $actualtime = self::getActualTime($actualtime, DAY_TIMESTAMP, $negative_delay);
+                        $delay      -= $timeoftheday;
                     } else {
                         // End of the delay in the day : get hours with this delay
                         $endhour = CalendarSegment::addDelayInDay(
@@ -616,6 +619,13 @@ class Calendar extends CommonDropdown
         return $actualdate;
     }
 
+    /**
+     * @param int $current_time
+     * @param int $number
+     * @param bool $negative
+     *
+     * @return int
+     */
     public static function getActualTime($current_time, $number = 0, $negative = false)
     {
         if ($negative) {
@@ -639,7 +649,7 @@ class Calendar extends CommonDropdown
         }
         $cache_duration = importArrayFromDB($this->fields['cache_duration']);
 
-       // Invalid cache duration : recompute it
+        // Invalid cache duration : recompute it
         if (!isset($cache_duration[0])) {
             $this->updateDurationCache($this->fields['id']);
             $cache_duration = importArrayFromDB($this->fields['cache_duration']);
@@ -704,11 +714,11 @@ class Calendar extends CommonDropdown
      */
     public static function getDayNumberInWeek($date)
     {
-        return (int)date('w', $date);
+        return (int) date('w', $date);
     }
 
     public static function getIcon()
     {
-        return "far fa-calendar-alt";
+        return "ti ti-calendar";
     }
 }
