@@ -38,4 +38,6 @@ namespace Glpi\Form\Export\Result;
 enum ImportError
 {
     case MISSING_DATA_REQUIREMENT;
+    case MISSING_CUSTOM_TYPE_REQUIREMENT;
+    case MISSING_PLUGIN_REQUIREMENT;
 }
