@@ -54,12 +54,12 @@ class LineOperator extends CommonDropdown
         return [['name'  => 'mcc',
             'label' => __('Mobile Country Code'),
             'type'  => 'integer',
-            'list'  => true
+            'list'  => true,
         ],
             ['name'  => 'mnc',
                 'label' => __('Mobile Network Code'),
                 'type'  => 'integer',
-                'list'  => true
+                'list'  => true,
             ],
         ];
     }
@@ -89,7 +89,6 @@ class LineOperator extends CommonDropdown
 
     public function prepareInputForAdd($input)
     {
-        /** @var \DBmysql $DB */
         global $DB;
 
         $input = parent::prepareInputForAdd($input);
@@ -101,21 +100,21 @@ class LineOperator extends CommonDropdown
             $input['mnc'] = 0;
         }
 
-       //check for mcc/mnc unicity
+        //check for mcc/mnc unicity
         $result = $DB->request([
             'COUNT'  => 'cpt',
             'FROM'   => self::getTable(),
             'WHERE'  => [
                 'mcc' => $input['mcc'],
-                'mnc' => $input['mnc']
-            ]
+                'mnc' => $input['mnc'],
+            ],
         ])->current();
 
         if ($result['cpt'] > 0) {
             Session::addMessageAfterRedirect(
-                __('Mobile country code and network code combination must be unique!'),
-                ERROR,
-                true
+                __s('Mobile country code and network code combination must be unique!'),
+                false,
+                ERROR
             );
             return false;
         }
