@@ -7,7 +7,7 @@
  *
  * http://glpi-project.org
  *
- * @copyright 2015-2023 Teclib' and contributors.
+ * @copyright 2015-2025 Teclib' and contributors.
  * @copyright 2003-2014 by the INDEPNET Development Team.
  * @licence   https://www.gnu.org/licenses/gpl-3.0.html
  *
@@ -33,12 +33,17 @@
  * ---------------------------------------------------------------------
  */
 
+use Glpi\Features\Clonable;
+
 /**
  * SolutionTemplate Class
  **/
 class SolutionTemplate extends AbstractITILChildTemplate
 {
-   // From CommonDBTM
+    /** @use Clonable<static> */
+    use Clonable;
+
+    // From CommonDBTM
     public $dohistory = true;
 
     public static $rightname = 'solutiontemplate';
@@ -63,16 +68,14 @@ class SolutionTemplate extends AbstractITILChildTemplate
                 'list'  => true,
             ],
             [
-                'name'           => 'content',
-                'label'          => __('Content'),
-                'type'           => 'tinymce',
-            // As content copying from template is not using the image pasting process, these images
-            // are not correctly processed. Indeed, document item corresponding to the destination item is not created and
-            // image src is not containing the ITIL item foreign key, so image will not be visible for helpdesk profiles.
-            // As fixing it is really complex (requires lot of refactoring in images handling, both on JS and PHP side),
-            // it is preferable to disable usage of images in templates.
-                'disable_images' => true,
-            ]
+                'name'  => 'content',
+                'label' => __('Content'),
+                'type'  => 'tinymce',
+                // Images should remains in base64 in templates.
+                // When an element will be created from a template, tinymce will catch the base64 image and trigger the
+                // document upload process.
+                'convert_images_to_documents' => false,
+            ],
         ];
     }
 
@@ -87,7 +90,7 @@ class SolutionTemplate extends AbstractITILChildTemplate
             'field'              => 'content',
             'table'              => $this->getTable(),
             'datatype'           => 'text',
-            'htmltext'           => true
+            'htmltext'           => true,
         ];
 
         $tab[] = [
@@ -95,7 +98,7 @@ class SolutionTemplate extends AbstractITILChildTemplate
             'name'               => SolutionType::getTypeName(1),
             'field'              => 'name',
             'table'              => getTableForItemType('SolutionType'),
-            'datatype'           => 'dropdown'
+            'datatype'           => 'dropdown',
         ];
 
         return $tab;
@@ -103,6 +106,11 @@ class SolutionTemplate extends AbstractITILChildTemplate
 
     public static function getIcon()
     {
-        return "fas fa-layer-group";
+        return "ti ti-stack-2-filled";
+    }
+
+    public function getCloneRelations(): array
+    {
+        return [];
     }
 }
